/**
 * AP_Platform.h
 *
 * Platform-dependent definitions for Engine Client, Correlator Plugin and
 * Common APIs.
 *
 * $Copyright(c) 2002-2006, 2008 Progress Software Corporation (PSC). All rights reserved.$
 * $Copyright (c) 2013-2014 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA, and/or its subsidiaries and/or its affiliates and/or their licensors.$
 * Use, reproduction, transfer, publication or disclosure is prohibited except as specifically provided for in your License Agreement with Software AG
 *
 * $Id: AP_Platform.h 249541 2015-03-09 11:42:24Z bsp $
 */

#ifndef AP_PLATFORM_H
#define AP_PLATFORM_H


#ifdef _WIN32
/*
 * DLL import/export symbols for Win32 builds.  Everything will work correctly
 * as long as the following symbols are *not* defined when this file is
 * included (These symbols are for Apama internal use only):
 *    AP_PLUGIN_API_BUILD
 *    AP_ENGINE_CLIENT_STATIC
 *    AP_ENGINE_CLIENT_BACKEND
 *    AP_COMMON_BACKEND
 */
#ifdef AP_PLUGIN_API_BUILD
#define AP_PLUGIN_DLL_SYM __declspec(dllimport)
#define AP_PLUGIN_API
#else
#define AP_PLUGIN_DLL_SYM __declspec(dllexport)
#define AP_PLUGIN_API __declspec(dllexport)
#endif
#define AP_PLUGIN_CALL   __stdcall

#ifndef AP_ENGINE_CLIENT_STATIC
#ifdef AP_ENGINE_CLIENT_BACKEND
#define AP_ENGINE_CLIENT_API __declspec(dllexport)
#else
#define AP_ENGINE_CLIENT_API __declspec(dllimport)
#endif
#else
#define AP_ENGINE_CLIENT_API
#endif
#define AP_ENGINE_CLIENT_CALL __stdcall

#ifndef AP_ENGINE_UM_STATIC
#ifdef AP_ENGINE_UM_BACKEND
#define AP_ENGINE_UM_API __declspec(dllexport)
#else
#define AP_ENGINE_UM_API __declspec(dllimport)
#endif
#else
#define AP_ENGINE_UM_API
#endif
#define AP_ENGINE_UM_CALL __stdcall


#ifdef AP_COMMON_BACKEND
#define AP_COMMON_API __declspec(dllexport)
#else
#define AP_COMMON_API __declspec(dllimport)
#endif
#define AP_COMMON_CALL __stdcall


#elif defined(_APBUILD_UNIX_ALL__) || defined(__unix__)
/*
 * Don't need any of these symbols for UNIX builds
 */
#define AP_PLUGIN_DLL_SYM
#define AP_PLUGIN_API
#define AP_PLUGIN_CALL

#define AP_ENGINE_CLIENT_API
#define AP_ENGINE_CLIENT_CALL

#define AP_ENGINE_UM_API
#define AP_ENGINE_UM_CALL


#define AP_COMMON_API
#define AP_COMMON_CALL


#else

#error "Can't determine platform: try #define _APBUILD_WIN32_ALL__ or _APBUILD_UNIX_ALL__"

#endif


#endif /* AP_PLATFORM_H */
